@@ -293,24 +293,14 @@ class Base(Controller):
         import pprint as pp
 
         if self.app.pargs.text=='ls':
-            import pandas as pd
-            pd.set_option('display.max_rows', 500)
-            
-            
-            data = list_models()['data']
-            df = pd.DataFrame.from_dict(data)
-            
-            if self.app.pargs.model != 'all':
-                # check if each row contains the model string
-                if self.app.pargs.model:
-                    df = df[df['root'].str.contains(self.app.pargs.model)]
-                
-                print(df)
-            else:
-                print(df)
+            list_models(self)
                 
         else:
-            suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions, self.app.pargs.model)
+            if self.app.pargs.model is None: model = 'code-davinci-002' 
+            else: model = self.app.pargs.model
+            suggestions = get_cai_suggestions(self.app.pargs.text, 
+                                              self.app.pargs.n_suggestions, 
+                                              model)
             try:
                 text = suggestions['choices'][0]['text']
                 pp.pprint(suggestions)
