@@ -38,8 +38,24 @@ def get_cai_suggestions(query: str, n_suggestions: int = 5, model = 'text-davinc
 
     return response_dict
 
+def list_models(ctx):
+    import pandas as pd
+    pd.set_option('display.max_rows', 500)
+    
+    
+    data = list_current_models()['data']
+    df = pd.DataFrame.from_dict(data)
+    
+    if ctx.app.pargs.model != 'all':
+        # check if each row contains the model string
+        if ctx.app.pargs.model:
+            df = df[df['root'].str.contains(ctx.app.pargs.model)]
+        
+        print(df)
+    else:
+        print(df)
 
-def list_models():
+def list_current_models():
     # curl https://api.openai.com/v1/models \
     #   -H 'Authorization: Bearer YOUR_API_KEY'
     api_path = os.path.join(os.path.expanduser('~'), ".dt_config.json")
